@@ -131,6 +131,9 @@ class RpcExchangerClient:
         msg = ""
         chat = -1
         while raw_message is None:
+            if not self._chat_list:
+                await asyncio.sleep(1000)
+                continue
             raw_message = await self._pubsub.get_message(ignore_subscribe_messages=True)
             try:
                 json_content = json.loads(raw_message["data"].decode())
